==> kmago-0.5.1.tar.gz: kmago-0.5.1/kmago/ktransferwget.cpp <==
/***************************************************************************
                          ktransferwget.cpp  -  description
                             -------------------
    begin                : Mon Sep 18 2000
    copyright            : (C) 2000 by Sergio Moretti
    email                : sermore@libero.it
    revision             : $Revision: 1.9 $
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "ktransferwgetimpl.h"
#include "ktransferwget.h"

  
QString KTransferWget::getCmdPath() const {
  return impl()->getCmdPath();
}

void KTransferWget::setCmdPath(const QString &c) {
  impl()->setCmdPath(c);
}

bool KTransferWget::getPassiveFtp() const {
  return impl()->getPassiveFtp();
}

void KTransferWget::setPassiveFtp(bool p) {
  impl()->setPassiveFtp(p);
}

int KTransferWget::getReadTimeout() const {
  return impl()->getReadTimeout();
}

void KTransferWget::setReadTimeout(int t) {
  impl()->setReadTimeout(t);
}

bool KTransferWget::getHTTPCache() const {
  return impl()->getHTTPCache();
}

void KTransferWget::setHTTPCache(bool m) {
  impl()->setHTTPCache(m);
}

bool KTransferWget::getProxy() const {
  return impl()->getProxy();
}

void KTransferWget::setProxy(bool m) {
  impl()->setProxy(m);
}

QString KTransferWget::getProxyFTP() const {
  return impl()->getProxyFTP();
}

void KTransferWget::setProxyFTP(const QString &p) {
  impl()->setProxyFTP(p);
}

QString KTransferWget::getProxyHTTP() const {
  return impl()->getProxyHTTP();
}

void KTransferWget::setProxyHTTP(const QString &p) {
  impl()->setProxyHTTP(p);
}

int KTransferWget::getProxyPortFTP() const {
  return impl()->getProxyPortFTP();
}

void KTransferWget::setProxyPortFTP(int p) {
  impl()->setProxyPortFTP(p);
}

int KTransferWget::getProxyPortHTTP() const {
  return impl()->getProxyPortHTTP();
}

void KTransferWget::setProxyPortHTTP(int p) {
  impl()->setProxyPortHTTP(p);
}

QStringList KTransferWget::getNoProxyList() const {
  return impl()->getNoProxyList();
}

void KTransferWget::setNoProxyList(const QStringList &l) {
  impl()->setNoProxyList(l);
}

int KTransferWget::getSpeed() const {
  return impl()->getSpeed();
}

void KTransferWget::setSpeed(int s) {
  impl()->setSpeed(s);
}

KTransferWget::KTransferWget(KTransferWgetImpl *impl) : KTransfer(impl) {
}

KTransferWgetImpl * KTransferWget::impl() const {
  return dynamic_cast<KTransferWgetImpl*>(KTransfer::impl());
}

==> kmago_1.1.2.orig.tar.gz: kmago-1.1.2.orig/kmago/ktransferwget.cpp <==
/***************************************************************************
                          ktransferwget.cpp  -  description
                             -------------------
    begin                : Mon Sep 18 2000
    copyright            : (C) 2000 by Sergio Moretti
    email                : sermore@libero.it
    revision             : $Revision: 1.11 $
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#ifdef ENABLE_WGET

#include "ktransferwgetimpl.h"
#include "ktransferwget.h"

  
QString KTransferWget::getCmdPath() const {
  return impl()->getCmdPath();
}

void KTransferWget::setCmdPath(const QString &c) {
  impl()->setCmdPath(c);
}

bool KTransferWget::getPassiveFtp() const {
  return impl()->getPassiveFtp();
}

void KTransferWget::setPassiveFtp(bool p) {
  impl()->setPassiveFtp(p);
}

int KTransferWget::getReadTimeout() const {
  return impl()->getReadTimeout();
}

void KTransferWget::setReadTimeout(int t) {
  impl()->setReadTimeout(t);
}

bool KTransferWget::getHTTPCache() const {
  return impl()->getHTTPCache();
}

void KTransferWget::setHTTPCache(bool m) {
  impl()->setHTTPCache(m);
}

bool KTransferWget::getProxy() const {
  return impl()->getProxy();
}

void KTransferWget::setProxy(bool m) {
  impl()->setProxy(m);
}

QString KTransferWget::getProxyFTP() const {
  return impl()->getProxyFTP();
}

void KTransferWget::setProxyFTP(const QString &p) {
  impl()->setProxyFTP(p);
}

QString KTransferWget::getProxyHTTP() const {
  return impl()->getProxyHTTP();
}

void KTransferWget::setProxyHTTP(const QString &p) {
  impl()->setProxyHTTP(p);
}

int KTransferWget::getProxyPortFTP() const {
  return impl()->getProxyPortFTP();
}

void KTransferWget::setProxyPortFTP(int p) {
  impl()->setProxyPortFTP(p);
}

int KTransferWget::getProxyPortHTTP() const {
  return impl()->getProxyPortHTTP();
}

void KTransferWget::setProxyPortHTTP(int p) {
  impl()->setProxyPortHTTP(p);
}

QStringList KTransferWget::getNoProxyList() const {
  return impl()->getNoProxyList();
}

void KTransferWget::setNoProxyList(const QStringList &l) {
  impl()->setNoProxyList(l);
}

TransferSpeed KTransferWget::getSpeed() const {
  return impl()->getSpeed();
}

void KTransferWget::setSpeed(TransferSpeed s) {
  impl()->setSpeed(s);
}

bool KTransferWget::getIgnoreLength() const {
  return impl()->getIgnoreLength();
}

void KTransferWget::setIgnoreLength(bool v) {
  impl()->setIgnoreLength(v);
}

KTransferWget::KTransferWget(KTransferWgetImpl *impl) : KTransfer(impl) {
}

KTransferWgetImpl * KTransferWget::impl() const {
  return dynamic_cast<KTransferWgetImpl*>(KTransfer::impl());
}

#endif
